@@ -82,8 +82,9 @@ def getOnlyChildByName(dom, namespace, name):
         return None
 
     if len(kids) > 1:
-        raise WrongNumberOfChildren('%s node should have at most one child of type '
-                '{%s}%s' % (dom.tagName, namespace, name))
+        raise WrongNumberOfChildren(
+            '<%s> node should have at most one <%s xmlns="%s"/> child' %
+            (dom.tagName, name, namespace))
 
     return kids[0]
 
@@ -563,6 +564,7 @@ class Property(DBusConstruct, Typed):
 
         requestable = dom.getAttributeNS(XMLNS_TP, 'requestable')
         self.requestable = requestable != ''
+        self.sometimes_requestable = requestable == 'sometimes'
 
     def get_access(self):
         if self.access & self.ACCESS_READ and self.access & self.ACCESS_WRITE:
@@ -577,7 +579,10 @@ class Property(DBusConstruct, Typed):
 
         if self.immutable:
             descriptions.append("Immutable")
-        if self.requestable:
+
+        if self.sometimes_requestable:
+            descriptions.append("Sometimes requestable")
+        elif self.requestable:
             descriptions.append("Requestable")
 
         return ', '.join(descriptions)
